from setuptools import setup

setup(name='distributions_hkl',
      version='0.1',
      description='Gaussian distributions package by HKL (mlnd programme)',
      packages=['distributions_hkl'],
      author = 'Hein Ko Lwin',
      author_email = 'heinko94@gmail.com',
      zip_safe=False)
